%define major	27
%define libname	%mklibname exiv2_ %{major}
%define libdev	%mklibname exiv2 -d

Summary:	Command line tool to access EXIF data in image files
Name:		exiv2
Version:	0.27.5
Release:	%mkrel 1
License:	GPLv2+
Group:		Graphics
Url:		http://www.exiv2.org/
Source:		http://www.exiv2.org/builds/%{name}-%{version}-Source.tar.xz
Patch1:		exiv2-0.27.4-fix-pkgconfig-file.patch
Patch2:		CVE-2021-29457-exiv-0.27.4.patch
Patch3:		mga-fix-check-rpaths-errors.patch
BuildRequires:	cmake
BuildRequires:	doxygen
BuildRequires:	graphviz
BuildRequires:	python
BuildRequires:	libxslt-proc
BuildRequires:	lib64expat-devel
BuildRequires:	zlib1-devel

BuildRequires:	lib64curl-devel
BuildRequires: lib64ssh-devel

Obsoletes: phatch
Obsoletes: python-exiv2

%description
Exiv2 is a command line utility to access image metadata:
* print the Exif metadata of JPEG, TIFF and several RAW image formats as
  summary info, interpreted values, or the plain data for each tag
* print the IPTC metadata of JPEG images
* print, set and delete the JPEG comment of JPEG images
* set, add and delete Exif and IPTC metadata of JPEG images
* adjust the Exif timestamp (that's how it all started...)
* rename Exif image files according to the Exif timestamp
* extract, insert and delete Exif metadata, IPTC metadata and JPEG comments
* extract, insert and delete the thumbnail image embedded in the Exif metadata
* fix the Exif ISO setting of picture taken with Nikon cameras

%package -n	%{libname}
Summary:	Library to access EXIF data in image files
Group:		System/Libraries

%description -n	%{libname}
libexiv2 is a C++ library to access image metadata. libexiv2 is free
software.

The Exiv2 library provides:
* full read and write access to the Exif and IPTC metadata of
  an image through Exiv2 keys and standard C++ iterators
* a smart IPTC implementation that does not affect data that
  programs like Photoshop store in the same image segment
* Exif MakerNote support:
      o MakerNote tags can be accessed just like any other Exif metadata
      o a sophisticated write algorithm avoids corrupting the MakerNote:
          1) the MakerNote is not re-located if possible at all, and
          2) MakerNote Ifd offsets are re-calculated if the MakerNote 
             needs to be moved (for known Ifd MakerNotes)
* extract and delete methods for Exif thumbnails (both, JPEG and TIFF
  thumbnails)
* set methods for Exif thumbnails (JPEG only, TIFF thumbnails can be
  set from individual tags)
* complete API documentation (by Doxygen)

%package -n	%{libdev}
Summary: 	Headers and links to compile against the "%{libname}" library
Group:		Development/Libraries
Requires:	%{libname} = %{version}
Requires:	multiarch-utils
Provides:	libexiv-devel = %{version}

%description -n	%{libdev}
This package contains all files which one needs to compile programs using
the "%{libname}" library.

%package	doc
Summary:	Exiv2 library documentation
Group:		Documentation
BuildArch:	noarch

%description	doc
Exiv2 library documentation.

%prep
%setup -q -n %{name}-%{version}-Source
%apply_patches

# remove Apple filesystem cruft
find . -type f -name "._*" -delete

%build
# exiv2: embedded copy of exempi should be compiled with BanAllEntityUsage
# https://bugzilla.redhat.com/show_bug.cgi?id=888769
export CPPFLAGS="-DBanAllEntityUsage=1"
export MAKEFILES_TYPE='Unix Makefiles'
%cmake -G "$MAKEFILES_TYPE" \
      -DEXIV2_BUILD_SAMPLES=OFF \
      -DEXIV2_BUILD_PO=ON \
      -DEXIV2_BUILD_UNIT_TESTS=ON \
      -DEXIV2_ENABLE_XMP=ON \
      -DEXIV2_ENABLE_PNG=ON \
      -DEXIV2_ENABLE_NLS=ON \
      -DEXIV2_ENABLE_PRINTUCS2=ON \
      -DEXIV2_ENABLE_LENSDATA=ON \
      -DEXIV2_ENABLE_VIDEO=OFF \
      -DEXIV2_ENABLE_WEBREADY=OFF \
      -DEXIV2_ENABLE_CURL=OFF \
      -DEXIV2_ENABLE_SSH=OFF \
      -DEXIV2_ENABLE_BMFF=ON
%make_build

%install
%make_install -C build

%find_lang exiv2

%files -f %{name}.lang
%{_bindir}/*
%{_mandir}/man1/*

%files -n %{libname}
%{_libdir}/lib%{name}.so.%{major}*
%{_libdir}/lib%{name}.so.%{version}

%files -n %{libdev}
%{_libdir}/lib%{name}.so
%{_libdir}/pkgconfig/*
%{_libdir}/lib%{name}-xmp.a
%{_libdir}/cmake/%{name}/
%{_includedir}/*

%files doc
%doc doc/ChangeLog doc/cmd.txt


%changelog
* Wed Nov 10 2021 tex - 0.27.5-1pclos2021
- new version

* Mon Jul 05 2021 tex - 0.27.4-1pclos2021
- new version

* Tue Sep 01 2020 tex - 0.27.3-1pclos2020
- new version

* Wed Sep 04 2019 tex - 0.27.2-1pclos2019
- new version

* Tue Jun 04 2019 tex - 0.27.1-3pclos2019
- rebuild against updates

* Mon Jun 03 2019 tex - 0.27.1-2pclos2019
- rebuild against updates

* Fri May 17 2019 tex 0.27.1-1pclos2019
- 0.27.1
